==> iam-floyd-0.21.0.tar.gz: package/lib/index.d.ts <==
export { AccessLevel, All, Operator, OperatorModifier } from "./shared";
export { A4b } from "./generated/alexaforbusiness";
export { ExecuteApi } from "./generated/amazonapigateway";
export { Appflow } from "./generated/amazonappflow";
export { Appstream } from "./generated/amazonappstream2-0";
export { Athena } from "./generated/amazonathena";
export { Chime } from "./generated/amazonchime";
export { Clouddirectory } from "./generated/amazonclouddirectory";
export { Cloudfront } from "./generated/amazoncloudfront";
export { Cloudsearch } from "./generated/amazoncloudsearch";
export { Cloudwatch } from "./generated/amazoncloudwatch";
export { Logs } from "./generated/amazoncloudwatchlogs";
export { Synthetics } from "./generated/amazoncloudwatchsynthetics";
export { Codeguru } from "./generated/amazoncodeguru";
export { CodeguruProfiler } from "./generated/amazoncodeguruprofiler";
export { CodeguruReviewer } from "./generated/amazoncodegurureviewer";
export { CognitoIdentity } from "./generated/amazoncognitoidentity";
export { CognitoSync } from "./generated/amazoncognitosync";
export { CognitoIdp } from "./generated/amazoncognitouserpools";
export { Comprehend } from "./generated/amazoncomprehend";
export { Connect } from "./generated/amazonconnect";
export { Dlm } from "./generated/amazondatalifecyclemanager";
export { Detective } from "./generated/amazondetective";
export { Dynamodb } from "./generated/amazondynamodb";
export { Dax } from "./generated/amazondynamodbacceleratordax";
export { Ec2 } from "./generated/amazonec2";
export { Autoscaling } from "./generated/amazonec2autoscaling";
export { Imagebuilder } from "./generated/amazonec2imagebuilder";
export { Ec2InstanceConnect } from "./generated/amazonec2instanceconnect";
export { Elasticache } from "./generated/amazonelasticache";
export { Ebs } from "./generated/amazonelasticblockstore";
export { Ecr } from "./generated/amazonelasticcontainerregistry";
export { Ecs } from "./generated/amazonelasticcontainerservice";
export { Eks } from "./generated/amazonelasticcontainerserviceforkubernetes";
export { Elasticfilesystem } from "./generated/amazonelasticfilesystem";
export { ElasticInference } from "./generated/amazonelasticinference";
export { Elasticmapreduce } from "./generated/amazonelasticmapreduce";
export { Es } from "./generated/amazonelasticsearchservice";
export { Elastictranscoder } from "./generated/amazonelastictranscoder";
export { Events } from "./generated/amazoneventbridge";
export { Schemas } from "./generated/amazoneventbridgeschemas";
export { Forecast } from "./generated/amazonforecast";
export { Frauddetector } from "./generated/amazonfrauddetector";
export { Freertos } from "./generated/amazonfreertos";
export { Fsx } from "./generated/amazonfsx";
export { Gamelift } from "./generated/amazongamelift";
export { Glacier } from "./generated/amazonglacier";
export { Groundtruthlabeling } from "./generated/amazongroundtruthlabeling";
export { Guardduty } from "./generated/amazonguardduty";
export { Inspector } from "./generated/amazoninspector";
export { Kendra } from "./generated/amazonkendra";
export { Cassandra } from "./generated/amazonkeyspacesforapachecassandra";
export { Kinesis } from "./generated/amazonkinesis";
export { Kinesisanalytics } from "./generated/amazonkinesisanalytics";
export { KinesisanalyticsV2 } from "./generated/amazonkinesisanalyticsv2";
export { Firehose } from "./generated/amazonkinesisfirehose";
export { Kinesisvideo } from "./generated/amazonkinesisvideostreams";
export { Lex } from "./generated/amazonlex";
export { Lightsail } from "./generated/amazonlightsail";
export { Machinelearning } from "./generated/amazonmachinelearning";
export { Macie2 } from "./generated/amazonmacie";
export { Macie } from "./generated/amazonmacieclassic";
export { Managedblockchain } from "./generated/amazonmanagedblockchain";
export { Kafka } from "./generated/amazonmanagedstreamingforkafka";
export { Mechanicalturk } from "./generated/amazonmechanicalturk";
export { Ec2messages } from "./generated/amazonmessagedeliveryservice";
export { Mobileanalytics } from "./generated/amazonmobileanalytics";
export { Mq } from "./generated/amazonmq";
export { NeptuneDb } from "./generated/amazonneptune";
export { Personalize } from "./generated/amazonpersonalize";
export { Mobiletargeting } from "./generated/amazonpinpoint";
export { SesPinpoint } from "./generated/amazonpinpointemailservice";
export { SmsVoice } from "./generated/amazonpinpointsmsandvoiceservice";
export { Polly } from "./generated/amazonpolly";
export { Qldb } from "./generated/amazonqldb";
export { Quicksight } from "./generated/amazonquicksight";
export { Rds } from "./generated/amazonrds";
export { RdsData } from "./generated/amazonrdsdataapi";
export { RdsDb } from "./generated/amazonrdsiamauthentication";
export { Redshift } from "./generated/amazonredshift";
export { Rekognition } from "./generated/amazonrekognition";
export { Tag } from "./generated/amazonresourcegrouptaggingapi";
export { Route53 } from "./generated/amazonroute53";
export { Route53domains } from "./generated/amazonroute53domains";
export { Route53resolver } from "./generated/amazonroute53resolver";
export { S3 } from "./generated/amazons3";
export { Sagemaker } from "./generated/amazonsagemaker";
export { Ses } from "./generated/amazonses";
export { Ssmmessages } from "./generated/amazonsessionmanagermessagegatewayservice";
export { Sdb } from "./generated/amazonsimpledb";
export { Swf } from "./generated/amazonsimpleworkflowservice";
export { Sns } from "./generated/amazonsns";
export { Sqs } from "./generated/amazonsqs";
export { Storagegateway } from "./generated/amazonstoragegateway";
export { Sumerian } from "./generated/amazonsumerian";
export { Textract } from "./generated/amazontextract";
export { Transcribe } from "./generated/amazontranscribe";
export { Translate } from "./generated/amazontranslate";
export { Workdocs } from "./generated/amazonworkdocs";
export { Worklink } from "./generated/amazonworklink";
export { Workmail } from "./generated/amazonworkmail";
export { Workmailmessageflow } from "./generated/amazonworkmailmessageflow";
export { Workspaces } from "./generated/amazonworkspaces";
export { Wam } from "./generated/amazonworkspacesapplicationmanager";
export { ApplicationAutoscaling } from "./generated/applicationautoscaling";
export { Discovery } from "./generated/applicationdiscovery";
export { Arsenal } from "./generated/applicationdiscoveryarsenal";
export { Account } from "./generated/awsaccounts";
export { Amplify } from "./generated/awsamplify";
export { Appconfig } from "./generated/awsappconfig";
export { Appmesh } from "./generated/awsappmesh";
export { AppmeshPreview } from "./generated/awsappmeshpreview";
export { Appsync } from "./generated/awsappsync";
export { Artifact } from "./generated/awsartifact";
export { AutoscalingPlans } from "./generated/awsautoscaling";
export { Backup } from "./generated/awsbackup";
export { BackupStorage } from "./generated/awsbackupstorage";
export { Batch } from "./generated/awsbatch";
export { AwsPortal } from "./generated/awsbilling";
export { Budgets } from "./generated/awsbudgetservice";
export { Acm } from "./generated/awscertificatemanager";
export { AcmPca } from "./generated/awscertificatemanagerprivatecertificateauthority";
export { Chatbot } from "./generated/awschatbot";
export { Cloud9 } from "./generated/awscloud9";
export { Cloudformation } from "./generated/awscloudformation";
export { Cloudhsm } from "./generated/awscloudhsm";
export { Servicediscovery } from "./generated/awscloudmap";
export { Cloudtrail } from "./generated/awscloudtrail";
export { Codeartifact } from "./generated/awscodeartifact";
export { Codebuild } from "./generated/awscodebuild";
export { Codecommit } from "./generated/awscodecommit";
export { Codedeploy } from "./generated/awscodedeploy";
export { Codepipeline } from "./generated/awscodepipeline";
export { Signer } from "./generated/awscodesigningforamazonfreertos";
export { Codestar } from "./generated/awscodestar";
export { CodestarConnections } from "./generated/awscodestarconnections";
export { CodestarNotifications } from "./generated/awscodestarnotifications";
export { Config } from "./generated/awsconfig";
export { Awsconnector } from "./generated/awsconnectorservice";
export { Cur } from "./generated/awscostandusagereport";
export { Ce } from "./generated/awscostexplorerservice";
export { Dms } from "./generated/awsdatabasemigrationservice";
export { Dataexchange } from "./generated/awsdataexchange";
export { Deepcomposer } from "./generated/awsdeepcomposer";
export { Deeplens } from "./generated/awsdeeplens";
export { Deepracer } from "./generated/awsdeepracer";
export { Devicefarm } from "./generated/awsdevicefarm";
export { Directconnect } from "./generated/awsdirectconnect";
export { Ds } from "./generated/awsdirectoryservice";
export { Elasticbeanstalk } from "./generated/awselasticbeanstalk";
export { Mediaconnect } from "./generated/awselementalmediaconnect";
export { Mediaconvert } from "./generated/awselementalmediaconvert";
export { Medialive } from "./generated/awselementalmedialive";
export { Mediapackage } from "./generated/awselementalmediapackage";
export { MediapackageVod } from "./generated/awselementalmediapackagevod";
export { Mediastore } from "./generated/awselementalmediastore";
export { Mediatailor } from "./generated/awselementalmediatailor";
export { Fms } from "./generated/awsfirewallmanager";
export { Globalaccelerator } from "./generated/awsglobalaccelerator";
export { Glue } from "./generated/awsglue";
export { Groundstation } from "./generated/awsgroundstation";
export { Health } from "./generated/awshealthapisandnotifications";
export { Importexport } from "./generated/awsimportexportdiskservice";
export { Iot } from "./generated/awsiot";
export { Iot1click } from "./generated/awsiot1-click";
export { Iotanalytics } from "./generated/awsiotanalytics";
export { IotDeviceTester } from "./generated/awsiotdevicetester";
export { Iotevents } from "./generated/awsiotevents";
export { Greengrass } from "./generated/awsiotgreengrass";
export { Iotsitewise } from "./generated/awsiotsitewise";
export { Iotthingsgraph } from "./generated/awsiotthingsgraph";
export { Iq } from "./generated/awsiq";
export { IqPermission } from "./generated/awsiqpermissions";
export { Kms } from "./generated/awskeymanagementservice";
export { Lakeformation } from "./generated/awslakeformation";
export { Lambda } from "./generated/awslambda";
export { LicenseManager } from "./generated/awslicensemanager";
export { AwsMarketplace } from "./generated/awsmarketplace";
export { AwsMarketplaceCatalog } from "./generated/awsmarketplacecatalog";
export { AwsMarketplaceEntitlementService } from "./generated/awsmarketplaceentitlementservice";
export { AwsMarketplaceImageBuildingService } from "./generated/awsmarketplaceimagebuildingservice";
export { AwsMarketplaceManagement } from "./generated/awsmarketplacemanagementportal";
export { AwsMarketplaceMeteringService } from "./generated/awsmarketplacemeteringservice";
export { AwsMarketplaceProcurementSystemsIntegration } from "./generated/awsmarketplaceprocurementsystemsintegration";
export { Mgh } from "./generated/awsmigrationhub";
export { Mobilehub } from "./generated/awsmobilehub";
export { Opsworks } from "./generated/awsopsworks";
export { OpsworksCm } from "./generated/awsopsworksconfigurationmanagement";
export { Organizations } from "./generated/awsorganizations";
export { Outposts } from "./generated/awsoutposts";
export { Pi } from "./generated/awsperformanceinsights";
export { Pricing } from "./generated/awspricelist";
export { AwsMarketplacePrivate } from "./generated/awsprivatemarketplace";
export { PurchaseOrders } from "./generated/awspurchaseordersconsole";
export { Ram } from "./generated/awsresourceaccessmanager";
export { ResourceGroups } from "./generated/awsresourcegroups";
export { Robomaker } from "./generated/awsrobomaker";
export { Savingsplans } from "./generated/awssavingsplans";
export { Secretsmanager } from "./generated/awssecretsmanager";
export { Securityhub } from "./generated/awssecurityhub";
export { Sts } from "./generated/awssecuritytokenservice";
export { Serverlessrepo } from "./generated/awsserverlessapplicationrepository";
export { Sms } from "./generated/awsservermigrationservice";
export { Servicecatalog } from "./generated/awsservicecatalog";
export { Shield } from "./generated/awsshield";
export { Snowball } from "./generated/awssnowball";
export { Sso } from "./generated/awssso";
export { SsoDirectory } from "./generated/awsssodirectory";
export { States } from "./generated/awsstepfunctions";
export { Support } from "./generated/awssupport";
export { Ssm } from "./generated/awssystemsmanager";
export { ResourceExplorer } from "./generated/awstageditor";
export { Transfer } from "./generated/awstransferforsftp";
export { Trustedadvisor } from "./generated/awstrustedadvisor";
export { Waf } from "./generated/awswaf";
export { WafRegional } from "./generated/awswafregional";
export { Wafv2 } from "./generated/awswafv2";
export { Wellarchitected } from "./generated/awswell-architectedtool";
export { Xray } from "./generated/awsx-ray";
export { Applicationinsights } from "./generated/cloudwatchapplicationinsights";
export { Comprehendmedical } from "./generated/comprehendmedical";
export { ComputeOptimizer } from "./generated/computeoptimizer";
export { Dbqms } from "./generated/databasequerymetadataservice";
export { Datapipeline } from "./generated/datapipeline";
export { Datasync } from "./generated/datasync";
export { Elasticloadbalancing } from "./generated/elasticloadbalancing";
export { ElasticloadbalancingV2 } from "./generated/elasticloadbalancingv2";
export { AccessAnalyzer } from "./generated/iamaccessanalyzer";
export { Iam } from "./generated/identityandaccessmanagement";
export { Launchwizard } from "./generated/launchwizard";
export { Apigateway } from "./generated/manageamazonapigateway";
export { Networkmanager } from "./generated/networkmanager";
export { Servicequotas } from "./generated/servicequotas";

==> iam-floyd-0.23.0.tar.gz: package/lib/index.d.ts <==
export { AccessLevel, All, Operator, OperatorModifier } from "./shared";
export { A4b } from "./generated/alexaforbusiness";
export { ExecuteApi } from "./generated/amazonapigateway";
export { Appflow } from "./generated/amazonappflow";
export { Appstream } from "./generated/amazonappstream2-0";
export { Athena } from "./generated/amazonathena";
export { Chime } from "./generated/amazonchime";
export { Clouddirectory } from "./generated/amazonclouddirectory";
export { Cloudfront } from "./generated/amazoncloudfront";
export { Cloudsearch } from "./generated/amazoncloudsearch";
export { Cloudwatch } from "./generated/amazoncloudwatch";
export { Logs } from "./generated/amazoncloudwatchlogs";
export { Synthetics } from "./generated/amazoncloudwatchsynthetics";
export { Codeguru } from "./generated/amazoncodeguru";
export { CodeguruProfiler } from "./generated/amazoncodeguruprofiler";
export { CodeguruReviewer } from "./generated/amazoncodegurureviewer";
export { CognitoIdentity } from "./generated/amazoncognitoidentity";
export { CognitoSync } from "./generated/amazoncognitosync";
export { CognitoIdp } from "./generated/amazoncognitouserpools";
export { Comprehend } from "./generated/amazoncomprehend";
export { Connect } from "./generated/amazonconnect";
export { Dlm } from "./generated/amazondatalifecyclemanager";
export { Detective } from "./generated/amazondetective";
export { Dynamodb } from "./generated/amazondynamodb";
export { Dax } from "./generated/amazondynamodbacceleratordax";
export { Ec2 } from "./generated/amazonec2";
export { Autoscaling } from "./generated/amazonec2autoscaling";
export { Imagebuilder } from "./generated/amazonec2imagebuilder";
export { Ec2InstanceConnect } from "./generated/amazonec2instanceconnect";
export { Elasticache } from "./generated/amazonelasticache";
export { Ebs } from "./generated/amazonelasticblockstore";
export { Ecr } from "./generated/amazonelasticcontainerregistry";
export { Ecs } from "./generated/amazonelasticcontainerservice";
export { Eks } from "./generated/amazonelasticcontainerserviceforkubernetes";
export { Elasticfilesystem } from "./generated/amazonelasticfilesystem";
export { ElasticInference } from "./generated/amazonelasticinference";
export { Elasticmapreduce } from "./generated/amazonelasticmapreduce";
export { Es } from "./generated/amazonelasticsearchservice";
export { Elastictranscoder } from "./generated/amazonelastictranscoder";
export { Events } from "./generated/amazoneventbridge";
export { Schemas } from "./generated/amazoneventbridgeschemas";
export { Forecast } from "./generated/amazonforecast";
export { Frauddetector } from "./generated/amazonfrauddetector";
export { Freertos } from "./generated/amazonfreertos";
export { Fsx } from "./generated/amazonfsx";
export { Gamelift } from "./generated/amazongamelift";
export { Glacier } from "./generated/amazonglacier";
export { Groundtruthlabeling } from "./generated/amazongroundtruthlabeling";
export { Guardduty } from "./generated/amazonguardduty";
export { Honeycode } from "./generated/amazonhoneycode";
export { Inspector } from "./generated/amazoninspector";
export { Kendra } from "./generated/amazonkendra";
export { Cassandra } from "./generated/amazonkeyspacesforapachecassandra";
export { Kinesis } from "./generated/amazonkinesis";
export { Kinesisanalytics } from "./generated/amazonkinesisanalytics";
export { KinesisanalyticsV2 } from "./generated/amazonkinesisanalyticsv2";
export { Firehose } from "./generated/amazonkinesisfirehose";
export { Kinesisvideo } from "./generated/amazonkinesisvideostreams";
export { Lex } from "./generated/amazonlex";
export { Lightsail } from "./generated/amazonlightsail";
export { Machinelearning } from "./generated/amazonmachinelearning";
export { Macie2 } from "./generated/amazonmacie";
export { Macie } from "./generated/amazonmacieclassic";
export { Managedblockchain } from "./generated/amazonmanagedblockchain";
export { Kafka } from "./generated/amazonmanagedstreamingforapachekafka";
export { Mechanicalturk } from "./generated/amazonmechanicalturk";
export { Ec2messages } from "./generated/amazonmessagedeliveryservice";
export { Mobileanalytics } from "./generated/amazonmobileanalytics";
export { Mq } from "./generated/amazonmq";
export { NeptuneDb } from "./generated/amazonneptune";
export { Personalize } from "./generated/amazonpersonalize";
export { Mobiletargeting } from "./generated/amazonpinpoint";
export { SesPinpoint } from "./generated/amazonpinpointemailservice";
export { SmsVoice } from "./generated/amazonpinpointsmsandvoiceservice";
export { Polly } from "./generated/amazonpolly";
export { Qldb } from "./generated/amazonqldb";
export { Quicksight } from "./generated/amazonquicksight";
export { Rds } from "./generated/amazonrds";
export { RdsData } from "./generated/amazonrdsdataapi";
export { RdsDb } from "./generated/amazonrdsiamauthentication";
export { Redshift } from "./generated/amazonredshift";
export { Rekognition } from "./generated/amazonrekognition";
export { Tag } from "./generated/amazonresourcegrouptaggingapi";
export { Route53 } from "./generated/amazonroute53";
export { Route53domains } from "./generated/amazonroute53domains";
export { Route53resolver } from "./generated/amazonroute53resolver";
export { S3 } from "./generated/amazons3";
export { Sagemaker } from "./generated/amazonsagemaker";
export { Ses } from "./generated/amazonses";
export { Ssmmessages } from "./generated/amazonsessionmanagermessagegatewayservice";
export { Sdb } from "./generated/amazonsimpledb";
export { Swf } from "./generated/amazonsimpleworkflowservice";
export { Sns } from "./generated/amazonsns";
export { Sqs } from "./generated/amazonsqs";
export { Storagegateway } from "./generated/amazonstoragegateway";
export { Sumerian } from "./generated/amazonsumerian";
export { Textract } from "./generated/amazontextract";
export { Transcribe } from "./generated/amazontranscribe";
export { Translate } from "./generated/amazontranslate";
export { Workdocs } from "./generated/amazonworkdocs";
export { Worklink } from "./generated/amazonworklink";
export { Workmail } from "./generated/amazonworkmail";
export { Workmailmessageflow } from "./generated/amazonworkmailmessageflow";
export { Workspaces } from "./generated/amazonworkspaces";
export { Wam } from "./generated/amazonworkspacesapplicationmanager";
export { ApplicationAutoscaling } from "./generated/applicationautoscaling";
export { Discovery } from "./generated/applicationdiscovery";
export { Arsenal } from "./generated/applicationdiscoveryarsenal";
export { Account } from "./generated/awsaccounts";
export { Amplify } from "./generated/awsamplify";
export { Appconfig } from "./generated/awsappconfig";
export { Appmesh } from "./generated/awsappmesh";
export { AppmeshPreview } from "./generated/awsappmeshpreview";
export { Appsync } from "./generated/awsappsync";
export { Artifact } from "./generated/awsartifact";
export { AutoscalingPlans } from "./generated/awsautoscaling";
export { Backup } from "./generated/awsbackup";
export { BackupStorage } from "./generated/awsbackupstorage";
export { Batch } from "./generated/awsbatch";
export { AwsPortal } from "./generated/awsbilling";
export { Budgets } from "./generated/awsbudgetservice";
export { Acm } from "./generated/awscertificatemanager";
export { AcmPca } from "./generated/awscertificatemanagerprivatecertificateauthority";
export { Chatbot } from "./generated/awschatbot";
export { Cloud9 } from "./generated/awscloud9";
export { Cloudformation } from "./generated/awscloudformation";
export { Cloudhsm } from "./generated/awscloudhsm";
export { Servicediscovery } from "./generated/awscloudmap";
export { Cloudtrail } from "./generated/awscloudtrail";
export { Codeartifact } from "./generated/awscodeartifact";
export { Codebuild } from "./generated/awscodebuild";
export { Codecommit } from "./generated/awscodecommit";
export { Codedeploy } from "./generated/awscodedeploy";
export { Codepipeline } from "./generated/awscodepipeline";
export { Signer } from "./generated/awscodesigningforamazonfreertos";
export { Codestar } from "./generated/awscodestar";
export { CodestarConnections } from "./generated/awscodestarconnections";
export { CodestarNotifications } from "./generated/awscodestarnotifications";
export { Config } from "./generated/awsconfig";
export { Awsconnector } from "./generated/awsconnectorservice";
export { Cur } from "./generated/awscostandusagereport";
export { Ce } from "./generated/awscostexplorerservice";
export { Dms } from "./generated/awsdatabasemigrationservice";
export { Dataexchange } from "./generated/awsdataexchange";
export { Deepcomposer } from "./generated/awsdeepcomposer";
export { Deeplens } from "./generated/awsdeeplens";
export { Deepracer } from "./generated/awsdeepracer";
export { Devicefarm } from "./generated/awsdevicefarm";
export { Directconnect } from "./generated/awsdirectconnect";
export { Ds } from "./generated/awsdirectoryservice";
export { Elasticbeanstalk } from "./generated/awselasticbeanstalk";
export { Mediaconnect } from "./generated/awselementalmediaconnect";
export { Mediaconvert } from "./generated/awselementalmediaconvert";
export { Medialive } from "./generated/awselementalmedialive";
export { Mediapackage } from "./generated/awselementalmediapackage";
export { MediapackageVod } from "./generated/awselementalmediapackagevod";
export { Mediastore } from "./generated/awselementalmediastore";
export { Mediatailor } from "./generated/awselementalmediatailor";
export { Fms } from "./generated/awsfirewallmanager";
export { Globalaccelerator } from "./generated/awsglobalaccelerator";
export { Glue } from "./generated/awsglue";
export { Groundstation } from "./generated/awsgroundstation";
export { Health } from "./generated/awshealthapisandnotifications";
export { Importexport } from "./generated/awsimportexportdiskservice";
export { Iot } from "./generated/awsiot";
export { Iot1click } from "./generated/awsiot1-click";
export { Iotanalytics } from "./generated/awsiotanalytics";
export { IotDeviceTester } from "./generated/awsiotdevicetester";
export { Iotevents } from "./generated/awsiotevents";
export { Greengrass } from "./generated/awsiotgreengrass";
export { Iotsitewise } from "./generated/awsiotsitewise";
export { Iotthingsgraph } from "./generated/awsiotthingsgraph";
export { Iq } from "./generated/awsiq";
export { IqPermission } from "./generated/awsiqpermissions";
export { Kms } from "./generated/awskeymanagementservice";
export { Lakeformation } from "./generated/awslakeformation";
export { Lambda } from "./generated/awslambda";
export { LicenseManager } from "./generated/awslicensemanager";
export { AwsMarketplace } from "./generated/awsmarketplace";
export { AwsMarketplaceCatalog } from "./generated/awsmarketplacecatalog";
export { AwsMarketplaceEntitlementService } from "./generated/awsmarketplaceentitlementservice";
export { AwsMarketplaceImageBuildingService } from "./generated/awsmarketplaceimagebuildingservice";
export { AwsMarketplaceManagement } from "./generated/awsmarketplacemanagementportal";
export { AwsMarketplaceMeteringService } from "./generated/awsmarketplacemeteringservice";
export { AwsMarketplaceProcurementSystemsIntegration } from "./generated/awsmarketplaceprocurementsystemsintegration";
export { Mgh } from "./generated/awsmigrationhub";
export { Mobilehub } from "./generated/awsmobilehub";
export { Opsworks } from "./generated/awsopsworks";
export { OpsworksCm } from "./generated/awsopsworksconfigurationmanagement";
export { Organizations } from "./generated/awsorganizations";
export { Outposts } from "./generated/awsoutposts";
export { Pi } from "./generated/awsperformanceinsights";
export { Pricing } from "./generated/awspricelist";
export { AwsMarketplacePrivate } from "./generated/awsprivatemarketplace";
export { PurchaseOrders } from "./generated/awspurchaseordersconsole";
export { Ram } from "./generated/awsresourceaccessmanager";
export { ResourceGroups } from "./generated/awsresourcegroups";
export { Robomaker } from "./generated/awsrobomaker";
export { Savingsplans } from "./generated/awssavingsplans";
export { Secretsmanager } from "./generated/awssecretsmanager";
export { Securityhub } from "./generated/awssecurityhub";
export { Sts } from "./generated/awssecuritytokenservice";
export { Serverlessrepo } from "./generated/awsserverlessapplicationrepository";
export { Sms } from "./generated/awsservermigrationservice";
export { Servicecatalog } from "./generated/awsservicecatalog";
export { Shield } from "./generated/awsshield";
export { Snowball } from "./generated/awssnowball";
export { Sso } from "./generated/awssso";
export { SsoDirectory } from "./generated/awsssodirectory";
export { States } from "./generated/awsstepfunctions";
export { Support } from "./generated/awssupport";
export { Ssm } from "./generated/awssystemsmanager";
export { ResourceExplorer } from "./generated/awstageditor";
export { Transfer } from "./generated/awstransferforsftp";
export { Trustedadvisor } from "./generated/awstrustedadvisor";
export { Waf } from "./generated/awswaf";
export { WafRegional } from "./generated/awswafregional";
export { Wafv2 } from "./generated/awswafv2";
export { Wellarchitected } from "./generated/awswell-architectedtool";
export { Xray } from "./generated/awsx-ray";
export { Applicationinsights } from "./generated/cloudwatchapplicationinsights";
export { Comprehendmedical } from "./generated/comprehendmedical";
export { ComputeOptimizer } from "./generated/computeoptimizer";
export { Dbqms } from "./generated/databasequerymetadataservice";
export { Datapipeline } from "./generated/datapipeline";
export { Datasync } from "./generated/datasync";
export { Elasticloadbalancing } from "./generated/elasticloadbalancing";
export { ElasticloadbalancingV2 } from "./generated/elasticloadbalancingv2";
export { AccessAnalyzer } from "./generated/iamaccessanalyzer";
export { Iam } from "./generated/identityandaccessmanagement";
export { Launchwizard } from "./generated/launchwizard";
export { Apigateway } from "./generated/manageamazonapigateway";
export { Networkmanager } from "./generated/networkmanager";
export { Servicequotas } from "./generated/servicequotas";
